==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/ro-RO/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'câmpuri customizate',
    'manage'                    => 'Gestionează',
    'field'		                => 'Camp',
    'about_fieldsets_title'		=> 'Despre câmpuri',
    'about_fieldsets_text'		=> 'Seturile de câmpuri vă permit să grupați câmpurile personalizate care sunt frecvent utilizate pentru tipuri specifice de modele ale activelor.',
    'custom_format'             => 'Format Regex personalizat...',
    'encrypt_field'      	        => 'Criptați valoarea acestui câmp în baza de date',
    'encrypt_field_help'      => 'AVERTISMENT: Criptarea unui câmp o face imposibilă.',
    'encrypted'      	        => 'criptat',
    'fieldset'      	        => 'FIELDSET',
    'qty_fields'      	      => 'Câte câmpuri',
    'fieldsets'      	        => 'Fieldsets',
    'fieldset_name'           => 'Nume de câmp',
    'field_name'              => 'Numele domeniului',
    'field_values'            => 'Valorile câmpului',
    'field_values_help'       => 'Adăugați opțiuni selectabile, câte unul pe rând. Liniile goale, altele decât prima linie, vor fi ignorate.',
    'field_element'           => 'Element de formular',
    'field_element_short'     => 'Element',
    'field_format'            => 'Format',
    'field_custom_format'     => 'Format personalizat',
    'field_custom_format_help'     => 'Acest câmp vă permite să utilizați o expresie de tip regex pentru validare. Ar trebui să înceapă cu "regex:" - de exemplu, pentru a valida că o valoare de câmp conține un IMEI valid (15 cifre numerice), veti folosi <code>regex: / ^[0-9]{15}$ /</code>.',
    'required'   		          => 'Necesar',
    'req'   		              => 'Req.',
    'used_by_models'   		    => 'Folosit de modele',
    'order'   		            => 'Ordin',
    'create_fieldset'         => 'Setul de câmpuri noi',
    'update_fieldset'         => 'Actualizare Câmpuri',
    'fieldset_does_not_exist'   => 'Setul de câmp :id nu există',
    'fieldset_updated'         => 'Setare câmp actualizată',
    'create_fieldset_title' => 'Creați un nou set de câmpuri',
    'create_field'            => 'Noul câmp personalizat',
    'create_field_title' => 'Creați un nou câmp personalizat',
    'value_encrypted'      	        => 'Valoarea acestui câmp este criptată în baza de date. Numai utilizatorii de administrare vor putea vizualiza valoarea decriptată',
    'show_in_email'     => 'Includeți valoarea acestui câmp în e-mailurile trimise utilizatorului? Căsuțele criptate nu pot fi incluse în e-mailuri',
    'show_in_email_short'     => 'Include în e-mailuri.',
    'help_text' => 'Text de ajutor',
    'help_text_description' => 'Acesta este un text opțional care va apărea mai jos de elementele formularului în timp ce editezi un activ pentru a oferi informații contextuale pentru fiecare câmp.',
    'about_custom_fields_title' => 'Despre câmpuri personalizate',
    'about_custom_fields_text' => 'Câmpurile personalizate vă permit să adăugați atribute arbitrare la active.',
    'add_field_to_fieldset' => 'Adaugă câmp la un set de câmpuri',
    'make_optional' => 'Obligatoriu - faceți clic pentru a deveni opțional',
    'make_required' => 'Opțional - faceți clic pentru a deveni obligatoriu',
    'reorder' => 'Reordonare',
    'db_field' => 'Câmp în baza de date',
    'db_convert_warning' => 'AVERTISMENT. Acest câmp este în tabelul câmpurilor personalizate ca <code>:db_column</code> dar ar trebui să fie <code>:expected</code>.',
    'is_unique' => 'Această valoare trebuie să fie unică pentru toate activele',
    'unique' => 'Unică',
    'display_in_user_view' => 'Permite utilizatorului verificat să vizualizeze aceste valori în pagina lor View Assigned Assets',
    'display_in_user_view_table' => 'Vizibil utilizatorului',
    'auto_add_to_fieldsets' => 'Adauga automat acest lucru la fiecare nou set de campuri',
    'add_to_preexisting_fieldsets' => 'Adauga la orice seturi de campuri existente',
    'show_in_listview' => 'Afișare implicită în lista de vizualizări. Utilizatorii autorizați vor putea în continuare să afișeze/ascunde prin selectorul de coloană',
    'show_in_listview_short' => 'Arată în liste',
    'show_in_requestable_list_short' => 'Arată în lista de active care pot fi solicitate',
    'show_in_requestable_list' => 'Arată valoarea în lista de active solicitate. Câmpurile criptate nu vor fi afișate',
    'encrypted_options' => 'Acest câmp este criptat, astfel încât unele opțiuni de afișare nu vor fi disponibile.',

];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/ro-RO/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'câmpuri customizate',
    'manage'                    => 'Gestionează',
    'field'		                => 'Camp',
    'about_fieldsets_title'		=> 'Despre câmpuri',
    'about_fieldsets_text'		=> 'Seturile de câmpuri vă permit să grupați câmpurile personalizate care sunt frecvent utilizate pentru tipuri specifice de modele ale activelor.',
    'custom_format'             => 'Format Regex personalizat...',
    'encrypt_field'      	        => 'Criptați valoarea acestui câmp în baza de date',
    'encrypt_field_help'      => 'AVERTISMENT: Criptarea unui câmp o face imposibilă.',
    'encrypted'      	        => 'criptat',
    'fieldset'      	        => 'FIELDSET',
    'qty_fields'      	      => 'Câte câmpuri',
    'fieldsets'      	        => 'Fieldsets',
    'fieldset_name'           => 'Nume de câmp',
    'field_name'              => 'Numele domeniului',
    'field_values'            => 'Valorile câmpului',
    'field_values_help'       => 'Adăugați opțiuni selectabile, câte unul pe rând. Liniile goale, altele decât prima linie, vor fi ignorate.',
    'field_element'           => 'Element de formular',
    'field_element_short'     => 'Element',
    'field_format'            => 'Format',
    'field_custom_format'     => 'Format personalizat',
    'field_custom_format_help'     => 'Acest câmp vă permite să utilizați o expresie de tip regex pentru validare. Ar trebui să înceapă cu "regex:" - de exemplu, pentru a valida că o valoare de câmp conține un IMEI valid (15 cifre numerice), veti folosi <code>regex: / ^[0-9]{15}$ /</code>.',
    'required'   		          => 'Necesar',
    'req'   		              => 'Req.',
    'used_by_models'   		    => 'Folosit de modele',
    'order'   		            => 'Ordin',
    'create_fieldset'         => 'Setul de câmpuri noi',
    'update_fieldset'         => 'Actualizare Câmpuri',
    'fieldset_does_not_exist'   => 'Setul de câmp :id nu există',
    'fieldset_updated'         => 'Setare câmp actualizată',
    'create_fieldset_title' => 'Creați un nou set de câmpuri',
    'create_field'            => 'Noul câmp personalizat',
    'create_field_title' => 'Creați un nou câmp personalizat',
    'value_encrypted'      	        => 'Valoarea acestui câmp este criptată în baza de date. Numai utilizatorii de administrare vor putea vizualiza valoarea decriptată',
    'show_in_email'     => 'Includeți valoarea acestui câmp în e-mailurile trimise utilizatorului? Căsuțele criptate nu pot fi incluse în e-mailuri',
    'show_in_email_short' => 'Include în e-mailuri',
    'help_text' => 'Text de ajutor',
    'help_text_description' => 'Acesta este un text opțional care va apărea mai jos de elementele formularului în timp ce editezi un activ pentru a oferi informații contextuale pentru fiecare câmp.',
    'about_custom_fields_title' => 'Despre câmpuri personalizate',
    'about_custom_fields_text' => 'Câmpurile personalizate vă permit să adăugați atribute arbitrare la active.',
    'add_field_to_fieldset' => 'Adaugă câmp la un set de câmpuri',
    'make_optional' => 'Obligatoriu - faceți clic pentru a deveni opțional',
    'make_required' => 'Opțional - faceți clic pentru a deveni obligatoriu',
    'reorder' => 'Reordonare',
    'db_field' => 'Câmp în baza de date',
    'db_convert_warning' => 'AVERTISMENT. Acest câmp este în tabelul câmpurilor personalizate ca <code>:db_column</code> dar ar trebui să fie <code>:expected</code>.',
    'is_unique' => 'Această valoare trebuie să fie unică pentru toate activele',
    'unique' => 'Unică',
    'display_in_user_view' => 'Permite utilizatorului verificat să vizualizeze aceste valori în pagina lor View Assigned Assets',
    'display_in_user_view_table' => 'Vizibil utilizatorului',
    'auto_add_to_fieldsets' => 'Adauga automat acest lucru la fiecare nou set de campuri',
    'add_to_preexisting_fieldsets' => 'Adauga la orice seturi de campuri existente',
    'show_in_listview' => 'Afișare implicită în lista de vizualizări. Utilizatorii autorizați vor putea în continuare să afișeze/ascunde prin selectorul de coloană',
    'show_in_listview_short' => 'Arată în liste',
    'show_in_requestable_list_short' => 'Arată în lista de active care pot fi solicitate',
    'show_in_requestable_list' => 'Arată valoarea în lista de active solicitate. Câmpurile criptate nu vor fi afișate',
    'encrypted_options' => 'Acest câmp este criptat, astfel încât unele opțiuni de afișare nu vor fi disponibile.',
    'display_checkin' => 'Display in checkin forms',
    'display_checkout' => 'Display in checkout forms',

];
